end_process

Macro end_process 

macro_rules! end_process {
    ($error:expr, $($arg:tt)*) => { ... };
}
Print an error diagnostic and exit the process with the given code.

In debug builds, also emits the source file and line number before the message. The error message is only printed when the verbosity level is ≥ 1 (i.e. not completely silent).

Example

end_process!(1, "cannot open '{}'", path);